<?php

namespace Drupal\instagram_sync;

use Drupal\Core\Plugin\ContextAwarePluginInterface;

/**
 * Interface for API type plugins.
 */
interface APITypeInterface extends ContextAwarePluginInterface {

  /**
   * Imports plugin media object from api by params.
   *
   * @param array $params
   *   Query params.
   *
   * @return object|null
   *   Remote Query result.
   */
  public function importMedia(array $params): object|null;

  /**
   * Gets plugin instagram profile id by access_token.
   *
   * @param array $data
   *   Profile access token.
   *
   * @return string|null
   *   Returns profile id or null.
   */
  public function getProfileId(array $data): string|null;

  /**
   * Gets plugin API URL.
   *
   * @return string
   *   Returns URL to call.
   */
  public function getApiUrl(): string;

  /**
   * Provides function to update access info if necessary.
   *
   * @param array $data
   *   Profile access token.
   *
   * @return array|null
   *   Returns new access token or null.
   */
  public function refreshAccess(array $data): array|null;

}
