<?php

namespace Drupal\instagram_sync;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * API Type plugin manager.
 */
class ApiTypePluginManager extends DefaultPluginManager {

  /**
   * Static cache for discovered plugins mapping.
   *
   * @var array
   */
  protected $bundlePlugins = [];

  /**
   * Constructs APITypePluginManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler to invoke the alter hook with.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct(
      'Plugin/APIType',
      $namespaces,
      $module_handler,
      'Drupal\instagram_sync\APITypeInterface',
      'Drupal\instagram_sync\Annotation\APIType'
    );
    $this->alterInfo('instagram_sync_api_info');
    $this->setCacheBackend($cache_backend, 'instagram_sync_api_plugins');
  }

}
