<?php

namespace Drupal\instagram_sync\Utility;

/**
 * Provides interface for Instagram API Media object.
 */
interface InstagramAPIMediaInterface {

  /**
   * Gets Instagram media ID.
   *
   * @return string
   *   Returns media ID string value.
   */
  public function getId(): string;

  /**
   * Gets Instagram Media type.
   *
   * @return string
   *   Returns media type string value.
   */
  public function getMediaType(): string;

  /**
   * Gets Instagram Media caption.
   *
   * @return string
   *   Returns caption string value.
   */
  public function getCaption(): string;

  /**
   * Returns an array of InstagramApiRemoteResource objects.
   *
   * @return InstagramApiRemoteResource[]
   *   Array of InstagramApiRemoteResource objects
   */
  public function getMediaUrl(): array;

  /**
   * Returns an array of InstagramApiRemoteResource objects.
   *
   * @return InstagramApiRemoteResource[]
   *   Array of InstagramApiRemoteResource objects
   */
  public function getImageUrl(): array;

  /**
   * Gets Instagram Media likes count.
   *
   * @return int
   *   Returns likes count int value.
   */
  public function getLikeCount(): int;

  /**
   * Gets Instagram Media comments count.
   *
   * @return int
   *   Returns comments count int value.
   */
  public function getCommentsCount(): int;

  /**
   * Gets Instagram Media permalink.
   *
   * @return string
   *   Returns link to post.
   */
  public function getPermalink(): string;

  /**
   * Gets Instagram Media created timestamp.
   *
   * @return int
   *   Returns created timestamp int value.
   */
  public function getCreatedTime(): int;

}
